@@ -6,6 +6,7 @@
 		   as.double(x),
 		   as.double(y),
 		   as.double(z),
-		   ans=double(length(x)))
+		   ans=double(length(x)),
+                   PACKAGE = "bootstrap")
   return(junk$ans)
 }
